@@ -3,6 +3,7 @@
 #[macro_use] extern crate rocket;
 
 use rocket_contrib::serve::StaticFiles;
+use rocket::config::{Config, Environment};
 use clap::Parser;
 
 /// Simple program to greet a person
@@ -10,17 +11,23 @@ use clap::Parser;
 #[clap(author, version, about, long_about = None)]
 struct Args {
 
-    #[clap(short, long)]
+    #[clap(long)]
     path: String,
+
+    #[clap(long)]
+    port: u16
 }
 
-
-
 fn main() {
 
     let args = Args::parse();
 
-    rocket::ignite()
-        .mount("/files", StaticFiles::from(args.path))
+    let config = Config::build(Environment::Staging)
+        .address("127.0.0.1")
+        .port(args.port)
+        .unwrap();
+ 
+    rocket::custom(config)
+        .mount("/", StaticFiles::from(args.path))
         .launch();
 }
\ No newline at end of file
